@@ -1,4 +1,5 @@
 """miscellaneous functions"""
+
 import warnings
 import time
 import os
@@ -24,11 +25,12 @@ import fsspec
 import aiohttp
 from lxml import objectify
 
-logger = logging.getLogger('xsar.utils')
+logger = logging.getLogger("xsar.utils")
 logger.addHandler(logging.NullHandler())
 
 mem_monitor = True
 
+
 try:
     from psutil import Process
 except ImportError:
@@ -43,17 +45,15 @@ def _load_config():
     -------
     dict
     """
-    user_config_file = Path('~/.xsar/config.yml').expanduser()
-    default_config_file = files('xsar').joinpath('config.yml')
+    user_config_file = Path("~/.xsar/config.yml").expanduser()
+    default_config_file = files("xsar").joinpath("config.yml")
 
     if user_config_file.exists():
         config_file = user_config_file
     else:
         config_file = default_config_file
 
-    config = yaml.load(
-        config_file.open(),
-        Loader=yaml.FullLoader)
+    config = yaml.load(config_file.open(), Loader=yaml.FullLoader)
     return config
 
 
@@ -86,7 +86,7 @@ def timing(f):
 
     @wraps(f)
     def wrapper(*args, **kwargs):
-        mem_str = ''
+        mem_str = ""
         process = None
         if mem_monitor:
             process = Process(os.getpid())
@@ -96,9 +96,10 @@ def timing(f):
         endtime = time.time()
         if mem_monitor:
             endrss = process.memory_info().rss
-            mem_str = 'mem: %+.1fMb' % ((endrss - startrss) / (1024 ** 2))
+            mem_str = "mem: %+.1fMb" % ((endrss - startrss) / (1024**2))
         logger.debug(
-            'timing %s : %.2fs. %s' % (f.__name__, endtime - starttime, mem_str))
+            "timing %s : %.2fs. %s" % (f.__name__, endtime - starttime, mem_str)
+        )
         return result
 
     return wrapper
@@ -154,12 +155,14 @@ def haversine(lon1, lat1, lon2, lat2):
     a = np.sin(dlat / 2) ** 2 + np.cos(lat1) * np.cos(lat2) * np.sin(dlon / 2) ** 2
     c = 2 * np.arcsin(np.sqrt(a))
     r = 6371000  # Radius of earth in meters.
-    bearing = np.arctan2(np.sin(lon2 - lon1) * np.cos(lat2),
-                         np.cos(lat1) * np.sin(lat2) - np.sin(lat1) * np.cos(lat2) * np.cos(lon2 - lon1))
+    bearing = np.arctan2(
+        np.sin(lon2 - lon1) * np.cos(lat2),
+        np.cos(lat1) * np.sin(lat2) - np.sin(lat1) * np.cos(lat2) * np.cos(lon2 - lon1),
+    )
     return c * r, np.rad2deg(bearing)
 
 
-def minigrid(x, y, z, method='linear', dims=['x', 'y']):
+def minigrid(x, y, z, method="linear", dims=["x", "y"]):
     """
 
     Parameters
@@ -186,7 +189,7 @@ def minigrid(x, y, z, method='linear', dims=['x', 'y']):
     """
     x_u = np.unique(np.sort(x))
     y_u = np.unique(np.sort(y))
-    xx, yy = np.meshgrid(x_u, y_u, indexing='ij')
+    xx, yy = np.meshgrid(x_u, y_u, indexing="ij")
     ngrid = griddata((x, y), z, (xx, yy), method=method)
     return xr.DataArray(ngrid, dims=dims, coords={dims[0]: x_u, dims[1]: y_u})
 
@@ -240,7 +243,7 @@ def map_blocks_coords(da, func, func_kwargs={}, **kwargs):
 
         # get loc ((dim_0_start,dim_0_stop),(dim_1_start,dim_1_stop),...)
         try:
-            loc = block_info[None]['array-location']
+            loc = block_info[None]["array-location"]
         except TypeError:
             # map_blocks is feeding us some dummy block data to check output type and shape
             # so we juste generate dummy coords to be able to call f
@@ -248,7 +251,7 @@ def map_blocks_coords(da, func, func_kwargs={}, **kwargs):
             loc = tuple(zip((0,) * len(block.shape), block.shape))
 
         # use loc to get corresponding coordinates
-        coords_sel = tuple(c[loc[i][0]:loc[i][1]] for i, c in enumerate(coords))
+        coords_sel = tuple(c[loc[i][0] : loc[i][1]] for i, c in enumerate(coords))
 
         result = f(*coords_sel, **func_kwargs)
 
@@ -258,8 +261,8 @@ def map_blocks_coords(da, func, func_kwargs={}, **kwargs):
         return result
 
     coords = {c: da[c].values for c in da.dims}
-    if 'name' not in kwargs:
-        kwargs['name'] = dask.utils.funcname(func)
+    if "name" not in kwargs:
+        kwargs["name"] = dask.utils.funcname(func)
 
     meta = da.data
     dtype = meta.dtype
@@ -267,20 +270,17 @@ def map_blocks_coords(da, func, func_kwargs={}, **kwargs):
     from_coords = bind(_evaluate_from_coords, ..., ..., coords.values(), dtype=dtype)
 
     daskarr = meta.map_blocks(from_coords, func, meta=meta, **kwargs)
-    dataarr = xr.DataArray(daskarr,
-                           dims=da.dims,
-                           coords=coords
-                           )
+    dataarr = xr.DataArray(daskarr, dims=da.dims, coords=coords)
     return dataarr
 
 
-def bbox_coords(xs, ys, pad='extends'):
+def bbox_coords(xs, ys, pad="extends"):
     """
     [(xs[0]-padx, ys[0]-pady), (xs[0]-padx, ys[-1]+pady), (xs[-1]+padx, ys[-1]+pady), (xs[-1]+padx, ys[0]-pady)]
     where padx and pady are xs and ys spacing/2
     """
     bbox_norm = [(0, 0), (0, -1), (-1, -1), (-1, 0)]
-    if pad == 'extends':
+    if pad == "extends":
         xdiff, ydiff = [np.unique(np.diff(d))[0] for d in (xs, ys)]
         xpad = (-xdiff / 2, xdiff / 2)
         ypad = (-ydiff / 2, ydiff / 2)
@@ -291,16 +291,17 @@ def bbox_coords(xs, ys, pad='extends'):
         xpad = (-pad[0], pad[0])
         ypad = (-pad[1], pad[1])
     # use apad and xpad to get surrounding box
-    bbox_ext = [
-        (
-            xs[x] + xpad[x],
-            ys[y] + ypad[y]
-        ) for x, y in bbox_norm
-    ]
+    bbox_ext = [(xs[x] + xpad[x], ys[y] + ypad[y]) for x, y in bbox_norm]
     return bbox_ext
 
 
-def compress_safe(safe_path_in, safe_path_out, product='S1', smooth=0, rasterio_kwargs={'compress': 'zstd'}):
+def compress_safe(
+    safe_path_in,
+    safe_path_out,
+    product="S1",
+    smooth=0,
+    rasterio_kwargs={"compress": "zstd"},
+):
     """
 
     Parameters
@@ -319,41 +320,50 @@ def compress_safe(safe_path_in, safe_path_out, product='S1', smooth=0, rasterio_
 
     """
 
-    safe_path_out_tmp = safe_path_out + '.tmp'
+    safe_path_out_tmp = safe_path_out + ".tmp"
     if os.path.exists(safe_path_out):
         raise FileExistsError("%s already exists" % safe_path_out)
     try:
         shutil.rmtree(safe_path_out_tmp)
-    except:
+    except IOError:
         pass
     os.mkdir(safe_path_out_tmp)
-    if 'S1' in product:
+    if "S1" in product:
         shutil.copytree(safe_path_in + "/annotation", safe_path_out_tmp + "/annotation")
-        shutil.copyfile(safe_path_in + "/manifest.safe", safe_path_out_tmp + "/manifest.safe")
+        shutil.copyfile(
+            safe_path_in + "/manifest.safe", safe_path_out_tmp + "/manifest.safe"
+        )
 
         os.mkdir(safe_path_out_tmp + "/measurement")
-        for tiff_file in glob.glob(os.path.join(safe_path_in, 'measurement', '*.tiff')):
+        for tiff_file in glob.glob(os.path.join(safe_path_in, "measurement", "*.tiff")):
             src = rasterio.open(tiff_file)
             open_kwargs = src.profile
             open_kwargs.update(rasterio_kwargs)
             gcps, crs = src.gcps
-            open_kwargs['gcps'] = gcps
-            open_kwargs['crs'] = crs
+            open_kwargs["gcps"] = gcps
+            open_kwargs["crs"] = crs
             if smooth > 1:
                 reduced = xr.DataArray(
                     src.read(
-                        1, out_shape=(src.height // smooth, src.width // smooth),
-                        resampling=rasterio.enums.Resampling.rms))
+                        1,
+                        out_shape=(src.height // smooth, src.width // smooth),
+                        resampling=rasterio.enums.Resampling.rms,
+                    )
+                )
                 mean = reduced.mean().item()
                 if not isinstance(mean, complex) and mean < 1:
-                    raise RuntimeError('rasterio returned empty band. Try to use smallest smooth size')
+                    raise RuntimeError(
+                        "rasterio returned empty band. Try to use smallest smooth size"
+                    )
                 reduced = reduced.assign_coords(
                     dim_0=reduced.dim_0 * smooth + smooth / 2,
-                    dim_1=reduced.dim_1 * smooth + smooth / 2)
+                    dim_1=reduced.dim_1 * smooth + smooth / 2,
+                )
                 band = reduced.interp(
                     dim_0=np.arange(src.height),
                     dim_1=np.arange(src.width),
-                    method='nearest')
+                    method="nearest",
+                )
                 try:
                     # convert to original datatype if possible
                     band = band.values.astype(src.dtypes[0])
@@ -363,39 +373,48 @@ def compress_safe(safe_path_in, safe_path_out, product='S1', smooth=0, rasterio_
                 band = src.read(1)
 
             with rasterio.open(
-                    safe_path_out_tmp + "/measurement/" + os.path.basename(tiff_file),
-                    'w',
-                    **open_kwargs
+                safe_path_out_tmp + "/measurement/" + os.path.basename(tiff_file),
+                "w",
+                **open_kwargs,
             ) as dst:
                 dst.write(band, 1)
-    elif 'RCM' in product:
+    elif "RCM" in product:
         shutil.copytree(safe_path_in + "/metadata", safe_path_out_tmp + "/metadata")
         shutil.copytree(safe_path_in + "/support", safe_path_out_tmp + "/support")
-        shutil.copyfile(safe_path_in + "/manifest.safe", safe_path_out_tmp + "/manifest.safe")
+        shutil.copyfile(
+            safe_path_in + "/manifest.safe", safe_path_out_tmp + "/manifest.safe"
+        )
 
         os.mkdir(safe_path_out_tmp + "/imagery")
-        for tiff_file in glob.glob(os.path.join(safe_path_in, 'imagery', '*.tif')):
+        for tiff_file in glob.glob(os.path.join(safe_path_in, "imagery", "*.tif")):
             src = rasterio.open(tiff_file)
             open_kwargs = src.profile
             open_kwargs.update(rasterio_kwargs)
             gcps, crs = src.gcps
-            open_kwargs['gcps'] = gcps
-            open_kwargs['crs'] = crs
+            open_kwargs["gcps"] = gcps
+            open_kwargs["crs"] = crs
             if smooth > 1:
                 reduced = xr.DataArray(
                     src.read(
-                        1, out_shape=(src.height // smooth, src.width // smooth),
-                        resampling=rasterio.enums.Resampling.rms))
+                        1,
+                        out_shape=(src.height // smooth, src.width // smooth),
+                        resampling=rasterio.enums.Resampling.rms,
+                    )
+                )
                 mean = reduced.mean().item()
                 if not isinstance(mean, complex) and mean < 1:
-                    raise RuntimeError('rasterio returned empty band. Try to use smallest smooth size')
+                    raise RuntimeError(
+                        "rasterio returned empty band. Try to use smallest smooth size"
+                    )
                 reduced = reduced.assign_coords(
                     dim_0=reduced.dim_0 * smooth + smooth / 2,
-                    dim_1=reduced.dim_1 * smooth + smooth / 2)
+                    dim_1=reduced.dim_1 * smooth + smooth / 2,
+                )
                 band = reduced.interp(
                     dim_0=np.arange(src.height),
                     dim_1=np.arange(src.width),
-                    method='nearest')
+                    method="nearest",
+                )
                 try:
                     # convert to original datatype if possible
                     band = band.values.astype(src.dtypes[0])
@@ -405,38 +424,47 @@ def compress_safe(safe_path_in, safe_path_out, product='S1', smooth=0, rasterio_
                 band = src.read(1)
 
             with rasterio.open(
-                    safe_path_out_tmp + "/imagery/" + os.path.basename(tiff_file),
-                    'w',
-                    **open_kwargs
+                safe_path_out_tmp + "/imagery/" + os.path.basename(tiff_file),
+                "w",
+                **open_kwargs,
             ) as dst:
                 dst.write(band, 1)
 
-    elif 'RS2' in product:
+    elif "RS2" in product:
         shutil.copytree(safe_path_in + "/schemas", safe_path_out_tmp + "/schemas")
-        for xml_file in glob.glob(os.path.join(safe_path_in, '*.xml')):
-            shutil.copyfile(xml_file, os.path.join(safe_path_out_tmp, os.path.basename(xml_file)))
-        for tiff_file in glob.glob(os.path.join(safe_path_in, '*.tif')):
+        for xml_file in glob.glob(os.path.join(safe_path_in, "*.xml")):
+            shutil.copyfile(
+                xml_file, os.path.join(safe_path_out_tmp, os.path.basename(xml_file))
+            )
+        for tiff_file in glob.glob(os.path.join(safe_path_in, "*.tif")):
             src = rasterio.open(tiff_file)
             open_kwargs = src.profile
             open_kwargs.update(rasterio_kwargs)
             gcps, crs = src.gcps
-            open_kwargs['gcps'] = gcps
-            open_kwargs['crs'] = crs
+            open_kwargs["gcps"] = gcps
+            open_kwargs["crs"] = crs
             if smooth > 1:
                 reduced = xr.DataArray(
                     src.read(
-                        1, out_shape=(src.height // smooth, src.width // smooth),
-                        resampling=rasterio.enums.Resampling.rms))
+                        1,
+                        out_shape=(src.height // smooth, src.width // smooth),
+                        resampling=rasterio.enums.Resampling.rms,
+                    )
+                )
                 mean = reduced.mean().item()
                 if not isinstance(mean, complex) and mean < 1:
-                    raise RuntimeError('rasterio returned empty band. Try to use smallest smooth size')
+                    raise RuntimeError(
+                        "rasterio returned empty band. Try to use smallest smooth size"
+                    )
                 reduced = reduced.assign_coords(
                     dim_0=reduced.dim_0 * smooth + smooth / 2,
-                    dim_1=reduced.dim_1 * smooth + smooth / 2)
+                    dim_1=reduced.dim_1 * smooth + smooth / 2,
+                )
                 band = reduced.interp(
                     dim_0=np.arange(src.height),
                     dim_1=np.arange(src.width),
-                    method='nearest')
+                    method="nearest",
+                )
                 try:
                     # convert to original datatype if possible
                     band = band.values.astype(src.dtypes[0])
@@ -446,9 +474,9 @@ def compress_safe(safe_path_in, safe_path_out, product='S1', smooth=0, rasterio_
                 band = src.read(1)
 
             with rasterio.open(
-                    os.path.join(safe_path_out_tmp, os.path.basename(tiff_file)),
-                    'w',
-                    **open_kwargs
+                os.path.join(safe_path_out_tmp, os.path.basename(tiff_file)),
+                "w",
+                **open_kwargs,
             ) as dst:
                 dst.write(band, 1)
 
@@ -457,7 +485,7 @@ def compress_safe(safe_path_in, safe_path_out, product='S1', smooth=0, rasterio_
     return safe_path_out
 
 
-class BlockingActorProxy():
+class BlockingActorProxy:
     # http://distributed.dask.org/en/stable/actors.html
     # like dask Actor, but no need to do .result() on methods
     # so the resulting instance is usable like the proxied instance
@@ -476,14 +504,18 @@ class BlockingActorProxy():
             try:
                 self._dask_client = get_client()
             except ValueError:
-                logger.info('BlockingActorProxy: Transparent proxy for %s' % self._cls.__name__)
+                logger.info(
+                    "BlockingActorProxy: Transparent proxy for %s" % self._cls.__name__
+                )
         elif isinstance(actor, dask.distributed.actor.Actor):
-            logger.debug('BlockingActorProxy: Reusing existing actor')
+            logger.debug("BlockingActorProxy: Reusing existing actor")
             self._actor = actor
 
         if self._dask_client is not None:
-            logger.debug('submit new actor')
-            self._actor_future = self._dask_client.submit(self._cls, *args, **kwargs, actors=True)
+            logger.debug("submit new actor")
+            self._actor_future = self._dask_client.submit(
+                self._cls, *args, **kwargs, actors=True
+            )
             self._actor = self._actor_future.result()
         elif self._actor is None:
             # transparent proxy: no future
@@ -502,6 +534,7 @@ class BlockingActorProxy():
         if not callable(attr):
             return attr
         else:
+
             @wraps(attr)
             def func(*args, **kwargs):
                 res = attr(*args, **kwargs)
@@ -517,16 +550,14 @@ class BlockingActorProxy():
         # make self serializable with pickle
         # https://docs.python.org/3/library/pickle.html#object.__reduce__
         kwargs = self._kwargs
-        kwargs['actor'] = self._actor
+        kwargs["actor"] = self._actor
         return partial(BlockingActorProxy, **kwargs), (self._cls, *self._args)
 
 
-def merge_yaml(yaml_strings_list,section=None):
+def merge_yaml(yaml_strings_list, section=None):
     # merge a list of yaml strings in one string
 
-    dict_like = yaml.safe_load(
-        '\n'.join(yaml_strings_list)
-    )
+    dict_like = yaml.safe_load("\n".join(yaml_strings_list))
     if section is not None:
         dict_like = {section: dict_like}
 
@@ -536,23 +567,23 @@ def merge_yaml(yaml_strings_list,section=None):
 def get_glob(strlist):
     # from list of str, replace diff by '?'
     def _get_glob(st):
-        stglob = ''.join(
+        stglob = "".join(
             [
-                '?' if len(charlist) > 1 else charlist[0]
+                "?" if len(charlist) > 1 else charlist[0]
                 for charlist in [list(set(charset)) for charset in zip(*st)]
             ]
         )
-        return re.sub(r'\?+', '*', stglob)
+        return re.sub(r"\?+", "*", stglob)
 
     strglob = _get_glob(strlist)
-    if strglob.endswith('*'):
+    if strglob.endswith("*"):
         strglob += _get_glob(s[::-1] for s in strlist)[::-1]
-        strglob = strglob.replace('**', '*')
+        strglob = strglob.replace("**", "*")
 
     return strglob
 
 
-def safe_dir(filename, path='.', only_exists=False):
+def safe_dir(filename, path=".", only_exists=False):
     """
     get dir path from safe filename.
 
@@ -585,34 +616,43 @@ def safe_dir(filename, path='.', only_exists=False):
 
     # this function is shared between sentinelrequest and xsar
 
-    if 'S1' in filename:
+    if "S1" in filename:
         regex = re.compile(
-            "(...)_(..)_(...)(.)_(.)(.)(..)_(........T......)_(........T......)_(......)_(......)_(....).SAFE")
+            "(...)_(..)_(...)(.)_(.)(.)(..)_(........T......)_(........T......)_(......)_(......)_(....).SAFE"
+        )
         template = string.Template(
-            "${MISSIONID}_${BEAM}_${PRODUCT}${RESOLUTION}_${LEVEL}${CLASS}${POL}_${STARTDATE}_${STOPDATE}_${ORBIT}_${TAKEID}_${PRODID}.SAFE")
-    elif 'S2' in filename:
+            "${MISSIONID}_${BEAM}_${PRODUCT}${RESOLUTION}_${LEVEL}${CLASS}${POL}_${STARTDATE}_${STOPDATE}_${ORBIT}_${TAKEID}_${PRODID}.SAFE"
+        )
+    elif "S2" in filename:
         # S2B_MSIL1C_20211026T094029_N0301_R036_T33SWU_20211026T115128.SAFE
-        #YYYYMMDDHHMMSS: the datatake sensing start time
-        #Nxxyy: the PDGS Processing Baseline number (e.g. N0204)
-        #ROOO: Relative Orbit number (R001 - R143)
-        #Txxxxx: Tile Number field*
+        # YYYYMMDDHHMMSS: the datatake sensing start time
+        # Nxxyy: the PDGS Processing Baseline number (e.g. N0204)
+        # ROOO: Relative Orbit number (R001 - R143)
+        # Txxxxx: Tile Number field*
         # second date if product discriminator
         regex = re.compile(
-            "(...)_(MSI)(...)_(........T......)_N(....)_R(...)_T(.....)_(........T......).SAFE")
+            "(...)_(MSI)(...)_(........T......)_N(....)_R(...)_T(.....)_(........T......).SAFE"
+        )
         template = string.Template(
-            "${MISSIONID}_${PRODUCT}${LEVEL}_${STARTDATE}_${PROCESSINGBL}_${ORBIT}_${TIlE}_${PRODID}.SAFE")
+            "${MISSIONID}_${PRODUCT}${LEVEL}_${STARTDATE}_${PROCESSINGBL}_${ORBIT}_${TIlE}_${PRODID}.SAFE"
+        )
     else:
-        raise Exception('mission not handle')
+        raise Exception("mission not handle")
     regroups = re.search(regex, filename)
     tags = {}
-    for itag, tag in enumerate(re.findall(r"\$\{([\w]+)\}", template.template), start=1):
+    for itag, tag in enumerate(
+        re.findall(r"\$\{([\w]+)\}", template.template), start=1
+    ):
         tags[tag] = regroups.group(itag)
 
-    startdate = datetime.datetime.strptime(
-        tags["STARTDATE"], '%Y%m%dT%H%M%S').replace(tzinfo=pytz.UTC)
-    tags['SAFE'] = regroups.group(0)
-    tags["missionid"] = tags["MISSIONID"][1:3].lower() # should be replaced by tags["MISSIONID"].lower()
-    tags["longmissionid"] = 'sentinel-%s' % tags["MISSIONID"][1:3].lower()
+    startdate = datetime.datetime.strptime(tags["STARTDATE"], "%Y%m%dT%H%M%S").replace(
+        tzinfo=pytz.UTC
+    )
+    tags["SAFE"] = regroups.group(0)
+    tags["missionid"] = tags["MISSIONID"][
+        1:3
+    ].lower()  # should be replaced by tags["MISSIONID"].lower()
+    tags["longmissionid"] = "sentinel-%s" % tags["MISSIONID"][1:3].lower()
     tags["year"] = startdate.strftime("%Y")
     tags["month"] = startdate.strftime("%m")
     tags["day"] = startdate.strftime("%d")
@@ -622,13 +662,15 @@ def safe_dir(filename, path='.', only_exists=False):
     filepath = None
     for p in path:
         # deprecation warnings (see https://github.com/oarcher/sentinelrequest/issues/4)
-        if '{missionid}' in p:
-            warnings.warn('{missionid} tag is deprecated. Update your path template to use {longmissionid}')
+        if "{missionid}" in p:
+            warnings.warn(
+                "{missionid} tag is deprecated. Update your path template to use {longmissionid}"
+            )
         filepath = string.Template(p).substitute(tags)
         if not filepath.endswith(filename):
             filepath = os.path.join(filepath, filename)
         if only_exists:
-            if not os.path.isfile(os.path.join(filepath,'manifest.safe')):
+            if not os.path.isfile(os.path.join(filepath, "manifest.safe")):
                 filepath = None
             else:
                 # a path was found. Stop iterating over path list
@@ -636,7 +678,7 @@ def safe_dir(filename, path='.', only_exists=False):
     return filepath
 
 
-def url_get(url, cache_dir=os.path.join(config['data_dir'], 'fsspec_cache')):
+def url_get(url, cache_dir=os.path.join(config["data_dir"], "fsspec_cache")):
     """
     Get fil from url, using caching.
 
@@ -660,11 +702,15 @@ def url_get(url, cache_dir=os.path.join(config['data_dir'], 'fsspec_cache')):
     Due to fsspec, the returned filename won't match the remote one.
     """
 
-    if '://' in url:
+    if "://" in url:
         with fsspec.open(
-                'filecache::%s' % url,
-                https={'client_kwargs': {'timeout': aiohttp.ClientTimeout(total=3600)}},
-                filecache={'cache_storage': os.path.join(os.path.join(config['data_dir'], 'fsspec_cache'))}
+            "filecache::%s" % url,
+            https={"client_kwargs": {"timeout": aiohttp.ClientTimeout(total=3600)}},
+            filecache={
+                "cache_storage": os.path.join(
+                    os.path.join(config["data_dir"], "fsspec_cache")
+                )
+            },
         ) as f:
             fname = f.name
     else:
@@ -672,6 +718,7 @@ def url_get(url, cache_dir=os.path.join(config['data_dir'], 'fsspec_cache')):
 
     return fname
 
+
 def get_geap_gains(path_aux_cal, mode, pols):
     """
     Find gains Geap associated with mode product and slice number from AUX_CAL.
@@ -680,12 +727,12 @@ def get_geap_gains(path_aux_cal, mode, pols):
 
     Parameters
     ----------
-    path_aux_cal: str 
+    path_aux_cal: str
 
     mode: str
         "IW" for example.
 
-    pols : list 
+    pols : list
         ["VV","VH"] for example;
 
 
@@ -695,9 +742,9 @@ def get_geap_gains(path_aux_cal, mode, pols):
         return a dict for the given (mode+pols).
         this dictionnary contains a dict with offboresight angle values and associated gains values
     """
-    with open(path_aux_cal, 'rb') as file:
+    with open(path_aux_cal, "rb") as file:
         xml = file.read()
-        
+
     root_aux = objectify.fromstring(xml)
     dict_gains = {}
 
@@ -705,29 +752,40 @@ def get_geap_gains(path_aux_cal, mode, pols):
         swath = calibrationParams.swath
         polarisation = calibrationParams.polarisation
 
-        if (mode in swath.text and polarisation in pols):
+        if mode in swath.text and polarisation in pols:
             dict_temp = {}
 
-            increment = calibrationParams.elevationAntennaPattern.elevationAngleIncrement
-            
-            valuesIQ = np.array([float(
-                e) for e in calibrationParams.elevationAntennaPattern['values'].text.split(' ')])
-            
+            increment = (
+                calibrationParams.elevationAntennaPattern.elevationAngleIncrement
+            )
+
+            valuesIQ = np.array(
+                [
+                    float(e)
+                    for e in calibrationParams.elevationAntennaPattern[
+                        "values"
+                    ].text.split(" ")
+                ]
+            )
+
             if valuesIQ.size == 1202:
-                gain = np.sqrt(valuesIQ[::2]**2+valuesIQ[1::2]**2)
+                gain = np.sqrt(valuesIQ[::2] ** 2 + valuesIQ[1::2] ** 2)
             elif valuesIQ.size == 601:
-                gain = 10**(valuesIQ/10)
-            else : 
-                raise ValueError(f"valuesIQ must be of size 601 (float) or 1202 (complex)")
-            #gain = np.sqrt(valuesIQ[::2]**2+valuesIQ[1::2]**2)
+                gain = 10 ** (valuesIQ / 10)
+            else:
+                raise ValueError(
+                    "valuesIQ must be of size 601 (float) or 1202 (complex)"
+                )
+            # gain = np.sqrt(valuesIQ[::2]**2+valuesIQ[1::2]**2)
 
             count = gain.size
-            ang = np.linspace(-((count - 1)/2) * increment,
-                              ((count - 1)/2) * increment, count)
+            ang = np.linspace(
+                -((count - 1) / 2) * increment, ((count - 1) / 2) * increment, count
+            )
 
             dict_temp["offboresightAngle"] = ang
             dict_temp["gain"] = gain
-            dict_gains[swath+"_"+polarisation] = dict_temp
+            dict_gains[swath + "_" + polarisation] = dict_temp
 
     return dict_gains
 
@@ -740,7 +798,7 @@ def get_gproc_gains(path_aux_pp1, mode, product):
 
     Parameters
     ----------
-    path_aux_pp1: str 
+    path_aux_pp1: str
 
     Returns
     ----------
@@ -750,36 +808,40 @@ def get_gproc_gains(path_aux_pp1, mode, product):
     """
 
     # Parse the XML file
-    with open(path_aux_pp1, 'rb') as file:
+    with open(path_aux_pp1, "rb") as file:
         xml = file.read()
     root_pp1 = objectify.fromstring(xml)
     dict_gains = {}
     for prd in root_pp1.productList.getchildren():
         for swathParams in prd.slcProcParams.swathParamsList.getchildren():
-            if (mode in swathParams.swath.text and product in prd.productId.text):
-                gains = [float(g) for g in swathParams.gain.text.split(' ')]
+            if mode in swathParams.swath.text and product in prd.productId.text:
+                gains = [float(g) for g in swathParams.gain.text.split(" ")]
                 key = swathParams.swath
                 dict_gains[key] = gains
     return dict_gains
 
 
-
 def get_path_aux_cal(aux_cal_name):
-    path = os.path.join(config["auxiliary_dir"],
-                        aux_cal_name[0:3]+"_AUX_CAL",
-                        aux_cal_name, 
-                        "data", 
-                        aux_cal_name[0:3].lower() + "-aux-cal.xml")
+    path = os.path.join(
+        config["auxiliary_dir"],
+        aux_cal_name[0:3] + "_AUX_CAL",
+        aux_cal_name,
+        "data",
+        aux_cal_name[0:3].lower() + "-aux-cal.xml",
+    )
     if not os.path.isfile(path):
         raise FileNotFoundError(f"File doesn't exist: {path}")
     return path
 
+
 def get_path_aux_pp1(aux_pp1_name):
-    path = os.path.join(config["auxiliary_dir"],
-                        aux_pp1_name[0:3]+"_AUX_PP1",
-                        aux_pp1_name, 
-                        "data", 
-                        aux_pp1_name[0:3].lower() + "-aux-pp1.xml")
+    path = os.path.join(
+        config["auxiliary_dir"],
+        aux_pp1_name[0:3] + "_AUX_PP1",
+        aux_pp1_name,
+        "data",
+        aux_pp1_name[0:3].lower() + "-aux-pp1.xml",
+    )
     if not os.path.isfile(path):
         raise FileNotFoundError(f"File doesn't exist: {path}")
-    return path
\ No newline at end of file
+    return path
